summaryrefslogtreecommitdiff
path: root/hash.c
diff options
context:
space:
mode:
authormatz <matz@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2006-09-11 19:08:25 +0000
committermatz <matz@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2006-09-11 19:08:25 +0000
commit026f734f4c26b5c28e258a9581c021303ec62083 (patch)
treeb93e8985682b0b4d46724b9ddc0a541d95c78d6e /hash.c
parentad0b87727df89ea54edb2d6a6b295147fbca55f8 (diff)
* hash.c (rb_hash_compare_by_identity): rename Hash#identical to
Hash#compare_by_identity. git-svn-id: svn+ssh://ci.ruby-lang.org/ruby/trunk@10912 b2dd03c8-39d4-4d8f-98ff-823fe69b080e
Diffstat (limited to 'hash.c')
-rw-r--r--hash.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/hash.c b/hash.c
index 337007c39e..02a40b0444 100644
--- a/hash.c
+++ b/hash.c
@@ -1482,22 +1482,22 @@ static struct st_hash_type identhash = {
/*
* call-seq:
- * hsh.identical => hsh
+ * hsh.compare_by_identity => hsh
*
* Makes <i>hsh</i> to compare its keys by their identity, i.e. it
* will consider exact same objects as same keys.
*
* h1 = { "a" => 100, "b" => 200, :c => "c" }
* h1["a"] #=> "a"
* h1.identical
* h1.identical? #=> true
* h1["a"] #=> nil # different objects.
* h1[:c] #=> "c" # same symbols are all same.
*
*/
static VALUE
-rb_hash_identical(VALUE hash)
+rb_hash_compare_by_identity(VALUE hash)
{
rb_hash_modify(hash);
RHASH(hash)->tbl->type = &identhash;
@@ -1507,15 +1507,15 @@ rb_hash_identical(VALUE hash)
/*
* call-seq:
- * hsh.identical? => true or false
+ * hsh.compare_by_identity? => true or false
*
* Returns <code>true</code> if <i>hsh</i> will compare its keys by
* their identity. Also see <code>Hash#identical</code>.
*
*/
static VALUE
-rb_hash_identical_p(VALUE hash)
+rb_hash_compare_by_identity_p(VALUE hash)
{
if (RHASH(hash)->tbl->type == &identhash) {
return Qtrue;
@@ -2372,8 +2372,8 @@ Init_Hash(void)
rb_define_method(rb_cHash,"key?", rb_hash_has_key, 1);
rb_define_method(rb_cHash,"value?", rb_hash_has_value, 1);
- rb_define_method(rb_cHash,"identical", rb_hash_identical, 0);
- rb_define_method(rb_cHash,"identical?", rb_hash_identical_p, 0);
+ rb_define_method(rb_cHash,"compare_by_identity", rb_hash_compare_by_identity, 0);
+ rb_define_method(rb_cHash,"compare_by_identity?", rb_hash_compare_by_identity_p, 0);
#ifndef __MACOS__ /* environment variables nothing on MacOS. */
origenviron = environ;
@@ -1482,22 +1482,22 @@ static struct st_hash_type identhash = {
*
* h1 = { "a" => 100, "b" => 200, :c => "c" }
- * h1["a"] #=> "a"
- * h1.identical
- * h1.identical? #=> true
- * h1["a"] #=> nil # different objects.
- * h1[:c] #=> "c" # same symbols are all same.
+ * h1["a"] #=> "a"
+ * h1.compare_by_identity
+ * h1.compare_by_identity? #=> true
+ * h1["a"] #=> nil # different objects.
+ * h1[:c] #=> "c" # same symbols are all same.
*
*/
@@ -1507,15 +1507,15 @@ rb_hash_identical(VALUE hash)
*
* Returns <code>true</code> if <i>hsh</i> will compare its keys by
- * their identity. Also see <code>Hash#identical</code>.
+ * their identity. Also see <code>Hash#compare_by_identity</code>.
*
*/